Cls

Print: Print
Color 15
Print "                            MMRPWR:"
Print "THIS PROGRAM ESTIMATES THE STATISTICAL POWER TO DETECT A"
Print "DICHOTOMOUS MODERATOR VARIABLE USING MODERATED MULTIPLE REGRESSION (MMR)"
Print "FOR SPECIFIED CONDITIONS OF:"
Print "              (A) MODERATING EFFECT SIZE,"
Print "              (B) TOTAL SAMPLE SIZE,"
Print "              (C) SAMPLE SIZES IN MODERATOR-BASED SUBGROUPS,"
Print "              (D) PREDICTOR-MODERATOR INTERCORRELATION, AND"
Print "              (E) PREDICTOR VARIABLE RANGE RESTRICTION"
Print
Color 15
Print "Citation: "
Color 15
Print "Aguinis, H., & Pierce, C. A.  (1998).  Statistical power computations for"; ""
Print "   detecting dichotomous moderator variables with moderated multiple regression."
Print "   Educational and Psychological Measurement, 58, 668-676."
Color 15
Print
Print "Contact information:"
Color 15
Print " Herman Aguinis"
Print " The George Washington University, haguinis@gwu.edu"
Print " https://www.hermanaguinis.com"
Print
Color 15
Print "Please Enter the Correlation Between Predictor X and Criterion Y"
Input "                 for GROUP 1"; rxyZ1
Print "Please Enter the Correlation Between Predictor X and Criterion Y"
Input "                 for GROUP 2"; rxyZ2
Print
Print "Please Enter the Correlation Between Predictors X and Z"
Input "                 for the Complete Sample"; rxz



Input "Please Enter the Sample Size for GROUP 1"; n1
Input "Please Enter the Sample Size for GROUP 2"; n2

Input "Please Enter the Standard Deviation for Predictor X in the Sample"; sds
Input "Please Enter the Standard Deviation for Predictor X in the Population"; sdp


FISHZ1 = .5 * Log((1 + rxyZ1) / (1 - rxyZ1))
FISHZ2 = .5 * Log((1 + rxyZ2) / (1 - rxyZ2))
ZD = Abs(FISHZ1 - FISHZ2)
FISHZ3 = .5 * Log((1 + rxz) / (1 - rxz))
RR = sds / sdp
N = n1 + n2
p1 = n1 / N

'Centering predictors

ZD = ZD - .398
FISHZ3 = FISHZ3 - .575
RR = RR - .6
N = N - 180
p1 = p1 - .3

'Computing 2-way product terms

RRZD = RR * ZD
RRN = RR * N
RRFISHZ3 = RR * FISHZ3
RRp1 = RR * p1
NZD = N * ZD
ZDp1 = ZD * p1
ZDFISHZ3 = ZD * FISHZ3
Np1 = N * p1
NFISHZ3 = N * FISHZ3
FISHZ3p1 = FISHZ3 * p1

estpower = 1.082 + (.5338 * RR) + (.0025 * N) + (.9708 * p1) + (.0317 * FISHZ3) + (1.6527 * ZD) + (1.212 * RRZD) + (.001 * RRN) - (.102 * RRFISHZ3) + (.166 * RRp1) + (.006 * NZD) + (2.3 * ZDp1) + (.087 * ZDFISHZ3) + (.002 * Np1) + (.178 * FISHZ3p1)

POWER = (Sin(estpower / 2)) * (Sin(estpower / 2))

ubnd = estpower + (.186 * 1.96)
lbnd = estpower - (.186 * 1.96)
lci = (Sin(lbnd / 2)) * (Sin(lbnd / 2))
uci = (Sin(ubnd / 2)) * (Sin(ubnd / 2))

If POWER > 1! Then POWER = 1!
If POWER < 0 Then POWER = 0

If lci > 1! Then lci = 1!
If lci < 0 Then lci = 0

If uci > 1! Then uci = 1!
If uci < 0 Then uci = 0


Print
Color 31
Print "                *** Estimated Power ="; POWER; "***"
Print "                *** 95% CI ="; lci; "to"; uci; "***"
Color 7
End


